MemoryLayout

Struct MemoryLayout 

pub struct MemoryLayout {
    pub string_offsets: HashMap<String, u32>,
    pub next_string_offset: u32,
    pub bytes_offsets: HashMap<Vec<u8>, u32>,
    pub next_bytes_offset: u32,
    pub set_id_counter: u32,
    pub object_heap_offset: u32,
    pub next_object_id: u32,
}
Memory layout information for string and object storage

Fields

string_offsets: HashMap<String, u32>next_string_offset: u32bytes_offsets: HashMap<Vec<u8>, u32>next_bytes_offset: u32set_id_counter: u32object_heap_offset: u32next_object_id: u32

Implementations

Source

impl MemoryLayout

pub fn new() -> Self

pub fn add_string(&mut self, s: &str) -> u32

Add a string to memory and return its offset

pub fn add_bytes(&mut self, b: &[u8]) -> u32

Add bytes to memory and return its offset

pub fn allocate_object(&mut self, size: u32) -> u32

Allocate space for an object instance, returns pointer to allocated memory

pub fn allocate_list(&mut self, element_count: u32) -> u32

Allocate space for a list, returns pointer to allocated memory